@@ -14,8 +14,13 @@ class Hdfs(DataStorage):
         hdfs_port = self.args["hdfsPort-input-dataset"]
         delimiter = self.args["delimiter"] if "delimiter" in self.args else ","
         input_file_format = self.args["inputFileFormat"] if "inputFileFormat" in self.args else "csv"
+        input_columns = self.args["input-columns"] if "input-columns" in self.args else "*"
+        columns_list = input_columns.split(",")
 
-        return self.spark.read.load("hdfs://"+hdfs_host+":"+hdfs_port+input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False)
+        if read_all is True:
+            return self.spark.read.load("hdfs://"+hdfs_host+":"+hdfs_port+input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False)
+        else:
+            return self.spark.read.load("hdfs://"+hdfs_host+":"+hdfs_port+input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False).select(*columns_list)
 
     # overriding abstract method
     def save_dataset(self, df, output_dest):
