@@ -13,7 +13,7 @@ class Mongo(DataStorage):
 
 
     # overriding abstract method
-    def load_dataset(self, spark, read_all=True, input_dest=None, header=True):
+    def load_dataset(self, read_all=True, input_dest=None, header=True):
 
         if input_dest is None:
             input_dest = self.args["input-dataset"]
@@ -21,7 +21,7 @@ class Mongo(DataStorage):
         db = input_dest.split["."][0]
         collection = input_dest.split["."][1]
 
-        df = spark.read.format("com.mongodb.spark.sql.DefaultSource")\
+        df = self.spark.read.format("com.mongodb.spark.sql.DefaultSource")\
             .option("uri", self.uri).option("database", db).option("collection", collection)\
             .load()
         return df
